@@ -116,19 +116,12 @@ def make_config_parser(custom_file: str = None) -> configparser.ConfigParser:
     return parser
 
 
-def _determine_quality(args: argparse.Namespace) -> str:
-    for quality in constants.QUALITIES:
-        if quality == constants.DEFAULT_QUALITY:
-            # Skip so we prioritize anything that overwrites the default quality.
-            pass
-        elif getattr(args, quality, None) or (
-            hasattr(args, "quality")
-            and args.quality is not None
-            and args.quality == constants.QUALITIES[quality]["flag"]
-        ):
+def _determine_quality(qual: str) -> str:
+    for quality, values in constants.QUALITIES.items():
+        if values["flag"] is not None and values["flag"] == qual:
             return quality
 
-    return constants.DEFAULT_QUALITY
+    return qual
 
 
 class ManimConfig(MutableMapping):
@@ -245,6 +238,7 @@ class ManimConfig(MutableMapping):
         "custom_folders",
         "disable_caching",
         "disable_caching_warning",
+        "dry_run",
         "enable_wireframe",
         "ffmpeg_loglevel",
         "format",
@@ -272,7 +266,9 @@ class ManimConfig(MutableMapping):
         "plugins",
         "preview",
         "progress_bar",
+        "quality",
         "save_as_gif",
+        "save_sections",
         "save_last_frame",
         "save_pngs",
         "scene_names",
@@ -290,6 +286,7 @@ class ManimConfig(MutableMapping):
         "use_projection_stroke_shaders",
         "verbosity",
         "video_dir",
+        "sections_dir",
         "fullscreen",
         "window_position",
         "window_size",
@@ -528,6 +525,7 @@ class ManimConfig(MutableMapping):
             "write_all",
             "save_pngs",
             "save_as_gif",
+            "save_sections",
             "preview",
             "show_in_file_browser",
             "log_to_file",
@@ -566,6 +564,7 @@ class ManimConfig(MutableMapping):
             "media_dir",
             "log_dir",
             "video_dir",
+            "sections_dir",
             "images_dir",
             "text_dir",
             "tex_dir",
@@ -591,14 +590,16 @@ class ManimConfig(MutableMapping):
             setattr(self, key, parser["CLI"].getfloat(key))
 
         # tuple keys
-        gui_location = tuple(map(int, re.split(";|,|-", parser["CLI"]["gui_location"])))
+        gui_location = tuple(
+            map(int, re.split(r"[;,\-]", parser["CLI"]["gui_location"])),
+        )
         setattr(self, "gui_location", gui_location)
 
         window_size = parser["CLI"][
             "window_size"
         ]  # if not "default", get a tuple of the position
         if window_size != "default":
-            window_size = tuple(map(int, re.split(";|,|-", window_size)))
+            window_size = tuple(map(int, re.split(r"[;,\-]", window_size)))
         setattr(self, "window_size", window_size)
 
         # plugins
@@ -628,6 +629,10 @@ class ManimConfig(MutableMapping):
         if val:
             setattr(self, "media_width", val)
 
+        val = parser["CLI"].get("quality", fallback="", raw=True)
+        if val:
+            self.quality = _determine_quality(val)
+
         return self
 
     def digest_args(self, args: argparse.Namespace) -> "ManimConfig":
@@ -655,14 +660,24 @@ class ManimConfig(MutableMapping):
         digesting any other CLI arguments.
 
         """
+        # if the input file is a config file, parse it properly
+        if args.file.suffix == ".cfg":
+            args.config_file = args.file
+
+        # if args.file is `-`, the animation code has to be taken from STDIN, so the
+        # input file path shouldn't be absolute, since that file won't be read.
+        if str(args.file) == "-":
+            self.input_file = args.file
+
         # if a config file has been passed, digest it first so that other CLI
         # flags supersede it
         if args.config_file:
             self.digest_file(args.config_file)
 
-        # If args.file is `-`, the animation code has to be taken from STDIN, so the
-        # input file path shouldn't be absolute, since that file won't be read.
-        self.input_file = Path(args.file).absolute() if args.file != "-" else args.file
+        # read input_file from the args if it wasn't set by the config file
+        if not self.input_file:
+            self.input_file = Path(args.file).absolute()
+
         self.scene_names = args.scene_names if args.scene_names is not None else []
         self.output_file = args.output_file
 
@@ -674,6 +689,7 @@ class ManimConfig(MutableMapping):
             "save_last_frame",
             "save_pngs",
             "save_as_gif",
+            "save_sections",
             "write_all",
             "disable_caching",
             "format",
@@ -693,6 +709,7 @@ class ManimConfig(MutableMapping):
             "zero_pad",
             "enable_wireframe",
             "force_window",
+            "dry_run",
         ]:
             if hasattr(args, key):
                 attr = getattr(args, key)
@@ -701,10 +718,6 @@ class ManimConfig(MutableMapping):
                 if attr is not None:
                     self[key] = attr
 
-        # dry_run is special because it can only be set to True
-        if getattr(args, "dry_run", False):
-            self["dry_run"] = True
-
         for key in [
             "media_dir",  # always set this one first
             "log_dir",
@@ -732,7 +745,7 @@ class ManimConfig(MutableMapping):
                 )
 
         # Handle the quality flags
-        self.quality = _determine_quality(args)
+        self.quality = _determine_quality(getattr(args, "quality", None))
 
         # Handle the -r flag.
         rflag = args.resolution
@@ -749,6 +762,7 @@ class ManimConfig(MutableMapping):
             for opt in [
                 "media_dir",
                 "video_dir",
+                "sections_dir",
                 "images_dir",
                 "text_dir",
                 "tex_dir",
@@ -888,6 +902,12 @@ class ManimConfig(MutableMapping):
         doc="Whether to save the rendered scene in .gif format (-i).",
     )
 
+    save_sections = property(
+        lambda self: self._d["save_sections"],
+        lambda self, val: self._set_boolean("save_sections", val),
+        doc="Whether to save single videos for each section in addition to the movie file.",
+    )
+
     enable_wireframe = property(
         lambda self: self._d["enable_wireframe"],
         lambda self, val: self._set_boolean("enable_wireframe", val),
@@ -900,6 +920,12 @@ class ManimConfig(MutableMapping):
         doc="Set to force window when using the opengl renderer",
     )
 
+    dry_run = property(
+        lambda self: self._d["dry_run"],
+        lambda self, val: self._set_boolean("dry_run", val),
+        doc="Enable dry_run so that no output files are generated and window is disabled.",
+    )
+
     @property
     def verbosity(self):
         """Logger verbosity; "DEBUG", "INFO", "WARNING", "ERROR", or "CRITICAL" (-v)."""
@@ -1106,6 +1132,8 @@ class ManimConfig(MutableMapping):
 
     @quality.setter
     def quality(self, qual: str) -> None:
+        if qual is None:
+            return
         if qual not in constants.QUALITIES:
             raise KeyError(f"quality must be one of {list(constants.QUALITIES.keys())}")
         q = constants.QUALITIES[qual]
@@ -1125,27 +1153,16 @@ class ManimConfig(MutableMapping):
     @property
     def dry_run(self):
         """Whether dry run is enabled."""
-        return (
-            self.write_to_movie is False
-            and self.write_all is False
-            and self.save_last_frame is False
-            and not self.format
-        )
+        return self._d["dry_run"]
 
     @dry_run.setter
     def dry_run(self, val: bool) -> None:
+        self._d["dry_run"] = val
         if val:
             self.write_to_movie = False
             self.write_all = False
             self.save_last_frame = False
             self.format = None
-        else:
-            raise ValueError(
-                "It is unclear what it means to set dry_run to "
-                "False.  Instead, try setting each option "
-                "individually. (write_to_movie, write_all, "
-                "save_last_frame, save_pngs, or save_as_gif)",
-            )
 
     @property
     def renderer(self):
@@ -1366,7 +1383,7 @@ class ManimConfig(MutableMapping):
             Traceback (most recent call last):
             KeyError: 'video_dir {media_dir}/videos/{module_name}/{quality} requires the following keyword arguments: module_name'
             >>> config.get_dir("video_dir", module_name="myfile").as_posix()
-            'my_media_dir/videos/myfile/1080p60.0'
+            'my_media_dir/videos/myfile/1080p60'
 
         Note the quality does not need to be passed as keyword argument since
         :class:`ManimConfig` does store information about quality.
@@ -1385,7 +1402,7 @@ class ManimConfig(MutableMapping):
             >>> config.get_dir(
             ...     "partial_movie_dir", module_name="myfile", scene_name="myscene"
             ... ).as_posix()
-            'my_media_dir/videos/myfile/1080p60.0/partial_movie_files/myscene'
+            'my_media_dir/videos/myfile/1080p60/partial_movie_files/myscene'
 
         Standard f-string syntax is used.  Arbitrary names can be used when
         defining directories, as long as the corresponding values are passed to
@@ -1408,6 +1425,7 @@ class ManimConfig(MutableMapping):
             "assets_dir",
             "media_dir",
             "video_dir",
+            "sections_dir",
             "images_dir",
             "text_dir",
             "tex_dir",
@@ -1427,7 +1445,7 @@ class ManimConfig(MutableMapping):
 
         all_args = {k: self._d[k] for k in dirs}
         all_args.update(kwargs)
-        all_args["quality"] = f"{self.pixel_height}p{self.frame_rate}"
+        all_args["quality"] = f"{self.pixel_height}p{self.frame_rate:g}"
 
         path = self._d[key]
         while "{" in path:
@@ -1465,6 +1483,12 @@ class ManimConfig(MutableMapping):
         doc="Directory to place videos (no flag).  See :meth:`ManimConfig.get_dir`.",
     )
 
+    sections_dir = property(
+        lambda self: self._d["sections_dir"],
+        lambda self, val: self._set_dir("sections_dir", val),
+        doc="Directory to place section videos (no flag).  See :meth:`ManimConfig.get_dir`.",
+    )
+
     images_dir = property(
         lambda self: self._d["images_dir"],
         lambda self, val: self._set_dir("images_dir", val),
