@@ -50,12 +50,16 @@ class AnimationGroup(Animation):
         return list(self.group)
 
     def begin(self) -> None:
+        if self.suspend_mobject_updating:
+            self.group.suspend_updating()
         for anim in self.animations:
             anim.begin()
 
     def finish(self) -> None:
         for anim in self.animations:
             anim.finish()
+        if self.suspend_mobject_updating:
+            self.group.resume_updating()
 
     def clean_up_from_scene(self, scene: Scene) -> None:
         for anim in self.animations:
