@@ -213,7 +213,7 @@ class MovingCamera(Camera):
                 continue
 
             # initialize scene critical points with first mobjects critical points
-            if scene_critical_x_left == None:
+            if scene_critical_x_left is None:
                 scene_critical_x_left = m.get_critical_point(LEFT)[0]
                 scene_critical_x_right = m.get_critical_point(RIGHT)[0]
                 scene_critical_y_up = m.get_critical_point(UP)[1]
