@@ -32,7 +32,7 @@ class MultiCamera(MovingCamera):
         self.allow_cameras_to_capture_their_own_display = (
             allow_cameras_to_capture_their_own_display
         )
-        MovingCamera.__init__(self, **kwargs)
+        super().__init__(**kwargs)
 
     def add_image_mobject_from_camera(self, image_mobject_from_camera):
         """Adds an ImageMobject that's been obtained from the camera
@@ -72,7 +72,7 @@ class MultiCamera(MovingCamera):
         """
         for imfc in self.image_mobjects_from_cameras:
             imfc.camera.reset()
-        MovingCamera.reset(self)
+        super().reset()
         return self
 
     def capture_mobjects(self, mobjects, **kwargs):
@@ -82,7 +82,7 @@ class MultiCamera(MovingCamera):
             if not self.allow_cameras_to_capture_their_own_display:
                 to_add = list_difference_update(to_add, imfc.get_family())
             imfc.camera.capture_mobjects(to_add, **kwargs)
-        MovingCamera.capture_mobjects(self, mobjects, **kwargs)
+        super().capture_mobjects(mobjects, **kwargs)
 
     def get_mobjects_indicating_movement(self):
         """Returns all mobjects whose movement implies that the camera
