@@ -22,7 +22,7 @@ for plugin in pkg_resources.iter_entry_points("manim.plugins"):
         # essentially this would be similar to `from plugin import *``
         # if not just import the module with the plugin name
         if hasattr(loaded_plugin, "__all__"):
-            for thing in loaded_plugin.__all__:
+            for thing in loaded_plugin.__all__:  # type: ignore
                 exec(f"{thing}=loaded_plugin.{thing}")
                 __all__.append(thing)
         else:
