@@ -201,7 +201,7 @@ class CairoRenderer:
         self,
         scene,
         static_mobjects: typing.Iterable[Mobject],
-    ) -> typing.Iterable[Mobject]:
+    ) -> typing.Optional[typing.Iterable[Mobject]]:
         """Compute and save the static frame, that will be reused at each frame to avoid to unecesseraly computer
         static mobjects.
 
@@ -219,7 +219,7 @@ class CairoRenderer:
         """
         if not static_mobjects:
             self.static_image = None
-            return
+            return None
         self.update_frame(scene, mobjects=static_mobjects)
         self.static_image = self.get_frame()
         return self.static_image
